<?php
/*
Plugin Name: Del.icio.us Daily Post Formatting
Plugin URI: http://wordpress.org/#
Description: Applies formatting to posts created by the delicious daily 
postings.
Author: Kevin Wetzels
Version: 1.1
Author URI: http://www.el73.be/drunkey-love/
*/

// Copyright (C) 2006 Kevin Wetzels
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

include_once(dirname(__FILE__).'/delicious-daily-post-parser.php');
include_once(dirname(__FILE__).'/delicious-daily-post-formatter.php');

class DeliciousDailyPostFormatting { 
	
	var $formats;
	var $bookmark_limit;

	function format($id) {
		$post = wp_get_single_post($id);
		$title = $post->post_title;
		$parser = new DeliciousDailyPostParser();
		if ($parser->isDeliciousDailyPost($title)) {
			$this->retrieve_formatting();
			$parsed_post = $parser->parse($title, $post->post_content);
			$formatter = new DeliciousDailyPostFormatter();
			$regular_post = $formatter->format($parsed_post, $this->formats, $this->bookmark_limit);
			if (get_magic_quotes_gpc()) {
				$post->post_title = $regular_post->title;
				$post->post_name = sanitize_title($post->post_title);
				$post->post_excerpt = $regular_post->excerpt;
				$post->post_content = $regular_post->content;
			} else {
				$post->post_title = addslashes($regular_post->title);
				$post->post_name = addslashes(sanitize_title($post->post_title));
				$post->post_excerpt = addslashes($regular_post->excerpt);
				$post->post_content = addslashes($regular_post->content);
			}
			wp_update_post($post);
		}
	}
	
	function on_activation() {
		$newline = "\n";
		$this->formats['title'] = 'links for %Y%-%m%-%d%';
		$this->formats['before_bookmarks'] = '<ul class="delicious">';
		$this->formats['bookmark'] = 
			'<li>' . $newline .
			'<div class="delicious-link">%nr% - <a href="%url%" title="%title%">%title%</a></div>' . $newline .
			'<div class="delicious-extended">%extended%</div>' . $newline .
			'<div class="delicious-tags">(tags: %tags%)</div>' . $newline .
			'</li>';
		$this->formats['after_bookmarks'] = '</ul>';
		$this->formats['excerpt'] = 'My links for %Y%-%m%-%d%';
		$this->formats['tag'] = '<a href="%tag-url%" title="More from %tag% on del.icio.us">%tag%</a>';
		$this->bookmark_limit = 0;
		$this->store_formatting();
	}
	
	function store_formatting() {
		add_option('ddpf_title_format', $this->formats['title'], 'The format of the title of Delicious Daily Posts');
		add_option('ddpf_before_bookmarks', $this->formats['before_bookmarks'], 'What should be printed before the bookmarks of a Delicious Daily Post');
		add_option('ddpf_bookmark_format', $this->formats['bookmark'], 'The format of a bookmark in the Delicious Daily Posts');
		add_option('ddpf_after_bookmarks', $this->formats['after_bookmarks'], 'What should be printed after the bookmarks of a Delicious Daily Post');
		add_option('ddpf_excerpt_format', $this->formats['excerpt'], 'The format of the content of Delicious Daily Posts');
		add_option('ddpf_tag_format', $this->formats['tag'], 'The format of a tag of Delicious Daily Posts');
		add_option('ddpf_bookmark_limit', $this->bookmark_limit, 'The limit for the number of bookmarks shown');
	}
	
	function update_formatting() {
		update_option('ddpf_title_format', $this->formats['title']);
		update_option('ddpf_before_bookmarks', $this->formats['before_bookmarks']);
		update_option('ddpf_bookmark_format', $this->formats['bookmark']);
		update_option('ddpf_after_bookmarks', $this->formats['after_bookmarks']);
		update_option('ddpf_excerpt_format', $this->formats['excerpt']);
		update_option('ddpf_tag_format', $this->formats['tag']);
		update_option('ddpf_bookmark_limit', $this->bookmark_limit);
	}
	
	function retrieve_formatting() {
		$this->formats['title'] = stripslashes(get_option('ddpf_title_format'));
		$this->formats['before_bookmarks'] = stripslashes(get_option('ddpf_before_bookmarks'));
		$this->formats['bookmark'] = stripslashes(get_option('ddpf_bookmark_format'));
		$this->formats['after_bookmarks'] = stripslashes(get_option('ddpf_after_bookmarks'));
		$this->formats['excerpt'] = stripslashes(get_option('ddpf_excerpt_format'));
		$this->formats['tag'] = stripslashes(get_option('ddpf_tag_format'));		
		$this->bookmark_limit = stripslashes(get_option('ddpf_bookmark_limit'));
	}
	
	function retrieve_variables() {
		$this->formats['title'] = $_POST['title_format'];
		$this->formats['before_bookmarks'] = $_POST['before_bookmarks'];
		$this->formats['bookmark'] = $_POST['bookmark_format'];
		$this->formats['after_bookmarks'] = $_POST['after_bookmarks'];
		$this->formats['excerpt'] = $_POST['excerpt_format'];
		$this->formats['tag'] = $_POST['tag_format'];
		$this->bookmark_limit = $_POST['bookmark_limit'];
	}

	function options_subpanel() {
		
		if (isset($_POST['info_update'])) {
			$this->retrieve_variables();
			$this->update_formatting();
			?>
			<div class="updated"><p><strong>
			<?php 
				_e('Options Saved');
			?>
			</strong></p></div>
		<?php
		}
		$this->retrieve_formatting();
		?>
		<div class="wrap">	
		<form method="post">
			<h2>Del.icio.us Daily Post Format</h2>
			<fieldset name="set1">
				<legend>Set the options for the format of the del.icio.us daily post.</legend>
				<p>
					The following placeholders can be used:
				</p>
				<ul>
					<li><code>%count%</code>: the amount of bookmarks in the post</li>
					<li><code>%&lt;date-variable&gt;%</code>: any one of the <a href="http://php.net/manual/function.date.php" title="Explanation on PHP.net">PHP date()</a> variables</li>
					<li><code>%nr%</code>: the number of the current bookmark in the post (only in the bookmark format)</li>
					<li><code>%url%</code>: the URL of the current bookmark in the post (only in the bookmark format)</li>
					<li><code>%title%</code>: the title of the current bookmark in the post (only in the bookmark format)</li>
					<li><code>%extended%</code>: the extended (description) of the current bookmark in the post (only in the bookmark format)</li>
					<li><code>%tags%</code>: the tags of the current bookmark in the post (only in the bookmark format)</li>
					<li><code>%bookmarks%</code>: the entire content of the post (only in the excerpt)</li>
					<li><code>%tag%</code>: the name of the current tag of the current bookmark (only in the tag format)</li>
					<li><code>%tag-url%</code>: the URL of the current tag of the current bookmark (only in the tag format)</li>
				</ul>
				<label for="title_format">Title format:</label><br />
				<input type="text" id="title_format" name="title_format" size="52" value="<?php echo htmlspecialchars($this->formats['title']);?>" /><br />
				<label for="before_bookmarks">Before bookmarks:</label><br />
				<input type="text" id="before_bookmarks" name="before_bookmarks" size="52" value="<?php echo htmlspecialchars($this->formats['before_bookmarks']);?>" /><br />
				<label for="bookmark_format">Bookmark format:</label><br />
				<textarea cols="50" rows="7" id="bookmark_format" name="bookmark_format"><?php echo htmlspecialchars($this->formats['bookmark']);?></textarea><br />
				<label for="after_bookmarks">After bookmarks:</label><br />
				<input type="text" id="after_bookmarks" name="after_bookmarks" size="52" value="<?php echo htmlspecialchars($this->formats['after_bookmarks']);?>" /><br />
				<label for="excerpt_format">Excerpt format:</label><br />
				<textarea cols="50" rows="7" id="excerpt_format" name="excerpt_format"><?php echo htmlspecialchars($this->formats['excerpt']);?></textarea><br />
				<label for="tag_format">Tag format:</label><br />
				<input type="text" id="tag_format" name="tag_format" size="52" value="<?php echo htmlspecialchars($this->formats['tag']);?>" /><br />
				<label for="bookmark_limit">Maximum number of bookmarks (0 = all):</label><br />
				<input type="text" id="bookmark_limit" name="bookmark_limit" size="3" value="<?php echo $this->bookmark_limit;?>" /><br />
			</fieldset>
			<div class="submit">
	  		<input type="submit" name="info_update" value="<?php _e('Update Options') ?> &raquo;" />
	  	</div>
		</form>
		</div>
	<?php
	}

	function add_to_options() {
		if (function_exists('add_options_page')) {
			add_options_page('options', 'Del.icio.us Daily Post Format', 0, basename(__FILE__), array(&$this, 'options_subpanel'));
		}
	}

}

$delicious_daily_post_formatting = new DeliciousDailyPostFormatting();
register_activation_hook(__FILE__, array(&$delicious_daily_post_formatting, 'on_activation'));
add_action('admin_menu', array(&$delicious_daily_post_formatting, 'add_to_options')); 
add_action('save_post', array(&$delicious_daily_post_formatting, 'format'));

?>